##  Description
Business capabilities are free of IT language; they are defined in business terms and serve as a common language everyone in the organization understands and refers to. They are relatively stable over time, providing guidance and supporting decision-making in a fast-changing environment (where other elements of the EA architecture, e.g., applications and technology, are changing quickly).
Business capabilities can describe different contexts of a company (e.g., strategy, business architecture, IT architecture, org units), but they don’t reflect those. They are an abstraction of the underlying functionality and flows.
The business capability fact sheet in SAP LeanIX is a high-level description of what a business does and can do, regardless of how it is done or the resources required.
Business capability is a crucial fact sheet type for all use cases your organization realizes with SAP LeanIX. We recommend that for the initial use case (application portfolio assessment), all organizations start with modeling business capabilities, along with applications, organization, and potentially IT components.
Overview of all relations to/from business capability:
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27416ef97a441014868da38a5365be3e_LowRes.png)
Business capability examples:
  * Level 1: Human Resources
Level 2: Employee Lifecycle Management
  * Level 1: Customer Relationship
Level 2: Order Management
